from drf_spectacular.utils import extend_schema, extend_schema_view

from console_base.api.viewsets import LCModelViewSet

from encipher.models import EncryptionKey
from .filters import EncryptionKeyFilter
from .serializers import EncryptionKeySerializer, EncryptionKeyDataTables
from ..authentication import PasetoAutoAuthentication


# ---------------------------------------------------------------------------
@extend_schema_view(
    list=extend_schema(summary='List Encryption Keys'),
    retrieve=extend_schema(summary='Get a Encryption Key'),
    create=extend_schema(summary='Create a Encryption Key'),
    update=extend_schema(summary='Update a Encryption Key'),
    partial_update=extend_schema(summary='Partially Update a Encryption Key'),
    destroy=extend_schema(summary='Delete a Encryption Key'),
)
class EncryptionKeyViewSet(LCModelViewSet):
    queryset = EncryptionKey.objects
    serializer_class = EncryptionKeySerializer
    datatables_serializer = EncryptionKeyDataTables
    filterset_class = EncryptionKeyFilter

    def get_authenticators(self):
        """
        Support auth verified by provided public key.
        """
        authenticators = super().get_authenticators()
        authenticators.insert(0, PasetoAutoAuthentication())
        return authenticators


__all__ = [
    'EncryptionKeyViewSet',
]
