from lcconfig.encryption import mask
from sequential_uuids.generators import uuid_time_nextval
from django.conf import settings
from django.core.management.base import BaseCommand
from encipher.keys import Ed25519PrivateKey


class Command(BaseCommand):
    help = """
        Generate a public / private Ed25519 key pair to include in console packages.
        The Canonical ID and Public Key must be saved in Aspen and / or Odoo.
    """

    def handle(self, *args, **options):
        canonical_id = uuid_time_nextval()
        private_key = Ed25519PrivateKey.generate()

        path = f'{settings.CONF_DIR}/{settings.PINNED_VERIFICATION_KEY_FILE}'
        self.stdout.write(f'\nSet settings.PINNED_VERIFICATION_KEY_CID to {canonical_id}')
        self.stdout.write(f'Private Key (save to {path})\n\n')
        self.stdout.write(
            private_key.private_bytes(password=mask(str(canonical_id)).encode()).decode(),
            ending='\n',
        )

        user = settings.PINNED_VERIFICATION_KEY_USER
        self.stdout.write(
            f'\nPublic Key (Save in Aspen with values below) \n'
            f'Name: {settings.UMBRELLA_API_KEY_NAME}\n'
            f'CID: {canonical_id}\n'
            f'User: {user.first_name} {user.last_name} ({user.cid})\n\n'
        )
        self.stdout.write(private_key.public_key.as_pem.decode(), ending='\n\n')
