from pyseto import Key as PasetoKey
from typing import Optional, TYPE_CHECKING

from django.contrib.auth import get_user_model

if TYPE_CHECKING:
    from sandbox.latchstring.models import User as UserType
    from .tokens import AccessToken

User = get_user_model()


def lookup_user_record(token: 'AccessToken') -> Optional['UserType']:
    """
    Lookup user record from token claims
    """
    lookup_creds = token.get_claimed_creds()
    if cid := lookup_creds.get('user_cid'):
        return User.objects.filter(cid=cid).first()
    elif email := lookup_creds.get('email'):
        return User.objects.filter(email=email).first()

    return None


def generate_kid(key):
    """
    Generate Paseto-based Key ID from the key string.

    v2 & v4 take Ed25519 keys. v1 takes RSA. v3 takes ECDSA.
    In descending order of likely key type.
    """
    for version in (4, 1, 3):
        try:
            return PasetoKey.new(
                version=version,
                purpose="public",
                key=key,
            ).to_paserk_id()
        except ValueError:
            continue
